Enum MatchDir

enum MatchDir

Match direction for the stack. Used in PEEK[a..b]/stack_match_peek_slice.

Variants

BottomToTop

from the bottom to the top of the stack

TopToBottom

from the top to the bottom of the stack

Implementations

impl Clone for MatchDir

fn clone(self: &Self) -> MatchDir

impl Copy for MatchDir

impl Debug for MatchDir

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for MatchDir

impl Freeze for MatchDir

impl PartialEq for MatchDir

fn eq(self: &Self, other: &MatchDir) -> bool

impl RefUnwindSafe for MatchDir

impl Send for MatchDir

impl StructuralPartialEq for MatchDir

impl Sync for MatchDir

impl Unpin for MatchDir

impl UnsafeUnpin for MatchDir

impl UnwindSafe for MatchDir

impl<T> Any for MatchDir

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MatchDir

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MatchDir

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MatchDir

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MatchDir

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for MatchDir

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for MatchDir

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MatchDir

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MatchDir

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>