PrattParserMap

Struct PrattParserMap 

pub struct PrattParserMap<'pratt, 'a, 'i, R, F, T, P = PrattParser<R>>
where R: RuleType, F: FnMut(Pair<'i, R>) -> T, P: PrattParserOps<R>,
{ /* private fields */ }
Product of calling map_primary on a PrattParser or ConstPrattParser, defines how expressions should be mapped.

Implementations

Source

impl<'pratt, 'a, 'i, R, F, T, P> PrattParserMap<'pratt, 'a, 'i, R, F, T, P>
where R: RuleType + 'pratt, F: FnMut(Pair<'i, R>) -> T, P: PrattParserOps<R> + 'pratt,

pub fn map_prefix<X>(self, prefix: X) -> Self
where X: FnMut(Pair<'i, R>, T) -> T + 'a,

Maps prefix operators with closure prefix.

pub fn map_postfix<X>(self, postfix: X) -> Self
where X: FnMut(T, Pair<'i, R>) -> T + 'a,

Maps postfix operators with closure postfix.

pub fn map_infix<X>(self, infix: X) -> Self
where X: FnMut(T, Pair<'i, R>, T) -> T + 'a,

Maps infix operators with a closure infix.

pub fn parse<I: Iterator<Item = Pair<'i, R>>>(&mut self, pairs: I) -> T

The last method to call on the provided pairs to execute the Pratt parser (previously defined using map_primary, map_prefix, map_postfix, and map_infix methods).

Panics

Panics if the input pairs contain a prefix operator with no map_prefix, an infix operator with no map_infix, a postfix operator with no map_postfix, or an unexpected token that is not a valid prefix, primary, infix, or postfix expression.