Struct Lines

struct Lines<'i> { ... }

Line iterator for Spans, created by Span::lines().

Iterates all lines that are at least partially covered by the span. Yielding a &str for each.

Implementations

impl<'i> Freeze for Lines<'i>

impl<'i> Iterator for Lines<'i>

fn next(self: &mut Self) -> Option<<Self as >::Item>

impl<'i> RefUnwindSafe for Lines<'i>

impl<'i> Send for Lines<'i>

impl<'i> Sync for Lines<'i>

impl<'i> Unpin for Lines<'i>

impl<'i> UnsafeUnpin for Lines<'i>

impl<'i> UnwindSafe for Lines<'i>

impl<I> IntoIterator for Lines<'i>

fn into_iter(self: Self) -> I

impl<T> Any for Lines<'i>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Lines<'i>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Lines<'i>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Lines<'i>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Lines<'i>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Lines<'i>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Lines<'i>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>