Struct LinesSpan
struct LinesSpan<'i> { ... }
Line iterator for Spans, created by Span::lines_span().
Iterates all lines that are at least partially covered by the span. Yielding a Span for each.
Implementations
impl<'i> Freeze for LinesSpan<'i>
impl<'i> Iterator for LinesSpan<'i>
fn next(self: &mut Self) -> Option<<Self as >::Item>
impl<'i> RefUnwindSafe for LinesSpan<'i>
impl<'i> Send for LinesSpan<'i>
impl<'i> Sync for LinesSpan<'i>
impl<'i> Unpin for LinesSpan<'i>
impl<'i> UnsafeUnpin for LinesSpan<'i>
impl<'i> UnwindSafe for LinesSpan<'i>
impl<I> IntoIterator for LinesSpan<'i>
fn into_iter(self: Self) -> I
impl<T> Any for LinesSpan<'i>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for LinesSpan<'i>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for LinesSpan<'i>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for LinesSpan<'i>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for LinesSpan<'i>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for LinesSpan<'i>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for LinesSpan<'i>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>