Position

Struct Position 

pub struct Position<'i> { /* private fields */ }
A cursor position in a &str which provides useful methods to manually parse that string.

Implementations

Source

impl<'i> Position<'i>

pub fn new(input: &str, pos: usize) -> Option<Position<'_>>

Attempts to create a new Position at the given position. If the specified position is an invalid index, or the specified position is not a valid UTF8 boundary, then None is returned.

Examples
let cheart = '💖';
let heart = "💖";
assert_eq!(Position::new(heart, 1), None);
assert_ne!(Position::new(heart, cheart.len_utf8()), None);
pub fn from_start(input: &'i str) -> Position<'i>

Creates a Position at the start of a &str.

Examples
let start = Position::from_start("");
assert_eq!(start.pos(), 0);
pub fn pos(&self) -> usize

Returns the byte position of this Position as a usize.

Examples
let input = "ab";
let mut start = Position::from_start(input);

assert_eq!(start.pos(), 0);
pub fn span(&self, other: &Position<'i>) -> Span<'i>

Creates a Span from two Positions.

Panics

Panics if the positions come from different inputs.

Examples
let input = "ab";
let start = Position::from_start(input);
let span = start.span(&start.clone());

assert_eq!(span.start(), 0);
assert_eq!(span.end(), 0);
pub fn line_col(&self) -> (usize, usize)

Returns the line and column number of this Position.

This is an O(n) operation, where n is the number of chars in the input. You better use pair.line_col() instead.

Panics

Panics if the position is out of bounds.

Examples
enum Rule {}

let input = "\na";
let mut state: Box<pest::ParserState<'_, Rule>> = pest::ParserState::new(input);
let mut result = state.match_string("\na");
assert!(result.is_ok());
assert_eq!(result.unwrap().position().line_col(), (2, 2));
pub fn line_of(&self) -> &'i str

Returns the entire line of the input that contains this Position.

Panics

Panics if the position is out of bounds (e.g., beyond the end of the input).

Examples
enum Rule {}

let input = "\na";
let mut state: Box<pest::ParserState<'_, Rule>> = pest::ParserState::new(input);
let mut result = state.match_string("\na");
assert!(result.is_ok());
assert_eq!(result.unwrap().position().line_of(), "a");