Type Alias ParseResult
type ParseResult = Result<S, S>
Type alias to simplify specifying the return value of chained closures.
ParseResulttype ParseResult = Result<S, S>
Type alias to simplify specifying the return value of chained closures.