Enum Assoc
enum Assoc
Associativity of an infix binary operator, used by Op::infix(Assoc).
Variants
-
Left Left operator associativity. Evaluate expressions from left-to-right.
-
Right Right operator associativity. Evaluate expressions from right-to-left.
Implementations
impl Clone for Assoc
fn clone(self: &Self) -> Assoc
impl Copy for Assoc
impl Debug for Assoc
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Assoc
impl Freeze for Assoc
impl PartialEq for Assoc
fn eq(self: &Self, other: &Assoc) -> bool
impl RefUnwindSafe for Assoc
impl Send for Assoc
impl StructuralPartialEq for Assoc
impl Sync for Assoc
impl Unpin for Assoc
impl UnsafeUnpin for Assoc
impl UnwindSafe for Assoc
impl<T> Any for Assoc
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Assoc
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Assoc
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Assoc
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Assoc
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Assoc
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Assoc
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Assoc
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Assoc
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>