Trait Parser
trait Parser<R: RuleType>
A trait with a single method that parses strings.
Required Methods
fn parse(rule: R, input: &str) -> Result<Pairs<'_, R>, Error<R>>Parses a
&strstarting fromrule.
Parsertrait Parser<R: RuleType>
A trait with a single method that parses strings.
fn parse(rule: R, input: &str) -> Result<Pairs<'_, R>, Error<R>>Parses a &str starting from rule.